@@ -6,6 +6,10 @@ by.gr = TRUE,  ...) {
 # Part of the ChemoSpec package
 # Bryan Hanson, DePauw University, Dec 2009
 
+	if (!requireNamespace("lattice", quietly = TRUE)) {
+		stop("You need to install package lattice to use this function")
+	}
+
 	chkSpectra(spectra)
 	
 	# Organize and compute the requested data
@@ -15,7 +19,7 @@ by.gr = TRUE,  ...) {
 		if (method == "iqr"){
 			y <- aaply(spectra$data, 2, seXyIqr)
 			df <- data.frame(x, y1 = y[,1], y2 = y[,2], y3 = y[,3])
-			p <- xyplot(y1 + y2 + y3 ~ x, data = df,
+			p <- lattice::xyplot(y1 + y2 + y3 ~ x, data = df,
 				col = c("black", "red", "red"), xlab = spectra$unit[1],
 				ylab = "Full Data Set, median +/- iqr", type = "l", ...)
 			plot(p)
@@ -26,7 +30,7 @@ by.gr = TRUE,  ...) {
 			y2 <- y1 + s
 			y3 <- y1 - s
 			df <- data.frame(x, y1, y2, y3)
-			p <- xyplot(y1 + y2 + y3 ~ x, data = df,
+			p <- lattice::xyplot(y1 + y2 + y3 ~ x, data = df,
 				col = c("black", "red", "red"), xlab = spectra$unit[1],
 				ylab = "Full Data Set, mean +/- sd", type = "l", ...)
 			plot(p)
@@ -35,7 +39,7 @@ by.gr = TRUE,  ...) {
 		if (method == "sem") {
 			y <- aaply(spectra$data, 2, seXy)
 			df <- data.frame(x, y1 = y[,1], y2 = y[,2], y3 = y[,3])
-			p <- xyplot(y1 + y2 + y3 ~ x, data = df,
+			p <- lattice::xyplot(y1 + y2 + y3 ~ x, data = df,
 				col = c("black", "red", "red"), xlab = spectra$unit[1],
 				ylab = "Full Data Set, mean +/- sem", type = "l", ...)
 			plot(p)
@@ -44,7 +48,7 @@ by.gr = TRUE,  ...) {
 		if (method == "mad") {
 			y <- aaply(spectra$data, 2, seXyMad)
 			df <- data.frame(x, y1 = y[,1], y2 = y[,2], y3 = y[,3])
-			p <- xyplot(y1 + y2 + y3 ~ x, data = df,
+			p <- lattice::xyplot(y1 + y2 + y3 ~ x, data = df,
 				col = c("black", "red", "red"), xlab = spectra$unit[1],
 				ylab = "Full Data Set, median +/- mad", type = "l", ...)
 			plot(p)
@@ -53,7 +57,7 @@ by.gr = TRUE,  ...) {
 		if (method == "sem95") {
 			y <- aaply(spectra$data, 2, seXy95)
 			df <- data.frame(x, y1 = y[,1], y2 = y[,2], y3 = y[,3])
-			p <- xyplot(y1 + y2 + y3 ~ x, data = df,
+			p <- lattice::xyplot(y1 + y2 + y3 ~ x, data = df,
 				col = c("black", "red", "red"), xlab = spectra$unit[1],
 				ylab = "Full Data Set, mean +/- 95% ci sem", type = "l", ...)
 			plot(p)
@@ -85,7 +89,7 @@ by.gr = TRUE,  ...) {
 				}
 
 			df1 <- df1[-1,]
-			p <- xyplot(y1 + y2 + y3 ~ x | z, data = df1,
+			p <- lattice::xyplot(y1 + y2 + y3 ~ x | z, data = df1,
 				col = c("black", "red", "red"), xlab = spectra$unit[1],
 				ylab = "median +/- iqr", type = "l",
 				strip.left = TRUE, strip = FALSE,
@@ -108,7 +112,7 @@ by.gr = TRUE,  ...) {
 				}
 
 			df1 <- df1[-1,]
-			p <- xyplot(y1 + y2 + y3 ~ x | z, data = df1,
+			p <- lattice::xyplot(y1 + y2 + y3 ~ x | z, data = df1,
 				col = c("black", "red", "red"), xlab = spectra$unit[1],
 				ylab = "mean +/- sd", type = "l",
 				strip.left = TRUE, strip = FALSE,
@@ -128,7 +132,7 @@ by.gr = TRUE,  ...) {
 				}
 
 			df1 <- df1[-1,]
-			p <- xyplot(y1 + y2 + y3 ~ x | z, data = df1,
+			p <- lattice::xyplot(y1 + y2 + y3 ~ x | z, data = df1,
 				col = c("black", "red", "red"), xlab = spectra$unit[1],
 				ylab = "mean +/- sem", type = "l",
 				strip.left = TRUE, strip = FALSE,
@@ -148,7 +152,7 @@ by.gr = TRUE,  ...) {
 				}
 
 			df1 <- df1[-1,]
-			p <- xyplot(y1 + y2 + y3 ~ x | z, data = df1,
+			p <- lattice::xyplot(y1 + y2 + y3 ~ x | z, data = df1,
 				col = c("black", "red", "red"), xlab = spectra$unit[1],
 				ylab = "median +/- mad", type = "l",
 				strip.left = TRUE, strip = FALSE,
@@ -168,7 +172,7 @@ by.gr = TRUE,  ...) {
 				}
 
 			df1 <- df1[-1,]
-			p <- xyplot(y1 + y2 + y3 ~ x | z, data = df1,
+			p <- lattice::xyplot(y1 + y2 + y3 ~ x | z, data = df1,
 				col = c("black", "red", "red"), xlab = spectra$unit[1],
 				ylab = "mean +/- 95 % ci sem", type = "l",
 				strip.left = TRUE, strip = FALSE,
